Purdue University
Author: Purdue Marketing and Media, Purdue University
Description: Learn about Purdue University, a major research university located in Lafayette, Indiana known for discoveries in science, technology, engineering and more.
Keywords: Purdue University, Boilermakers, Boilers, West Lafayette, Indiana, United States, college, university, higher education, academics, technology, engineering, agriculture, health sciences, liberal arts, libraries, research, athletics, Ross-Ade Stadium, Mackey Arena, employment, professors, astronauts, world food prize, nobel prize, real-world, innovation

Current
Students
Engage
With Purdue
Give
Now
Prospective
Students
Careers
Apply
Now
Research and
Partnerships

Purdue University, 610 Purdue Mall, West Lafayette, IN 47907, (765) 494-4600

2014 Purdue University | An equal access/equal opportunity university | Copyright Complaints | Maintained by Marketing and Media

If you have trouble accessing this page because of a disability, please contact Purdue Marketing and Media at online@purdue.edu.